@@ -1,16 +1,15 @@
 from .errorhandler import register_error_handlers
 from .helpers import (
-    BaseItemView,
     BaseModel,
     CustomFlask,
     PaginationMixin,
     register_api,
     register_blueprints,
 )
+from .httpclient import HttpClient, HttpClientFactory
 from .response import make_errmsg
 
 __all__ = (
-    "BaseItemView",
     "BaseModel",
     "CustomFlask",
     "PaginationMixin",
@@ -18,4 +17,6 @@ __all__ = (
     "register_blueprints",
     "make_errmsg",
     "register_error_handlers",
+    "HttpClientFactory",
+    "HttpClient",
 )
